PxArticulationGpuDataType

Enum PxArticulationGpuDataType 

#[repr(i32)]
pub enum PxArticulationGpuDataType {
Show 18 variants JointPosition = 0, JointVelocity = 1, JointAcceleration = 2, JointForce = 3, JointSolverForce = 4, JointTargetVelocity = 5, JointTargetPosition = 6, SensorForce = 7, RootTransform = 8, RootVelocity = 9, LinkTransform = 10, LinkVelocity = 11, LinkForce = 12, LinkTorque = 13, FixedTendon = 14, FixedTendonJoint = 15, SpatialTendon = 16, SpatialTendonAttachment = 17,
}
A description of the types of articulation data that may be directly written to and read from the GPU using the functions PxScene::copyArticulationData() and PxScene::applyArticulationData(). Types that are read-only may only be used in conjunction with PxScene::copyArticulationData(). Types that are write-only may only be used in conjunction with PxScene::applyArticulationData(). A subset of data types may be used in conjunction with both PxScene::applyArticulationData() and PxScene::applyArticulationData().

Variants



JointPosition = 0

The joint positions, read and write, see PxScene::copyArticulationData(), PxScene::applyArticulationData()



JointVelocity = 1

The joint velocities, read and write, see PxScene::copyArticulationData(), PxScene::applyArticulationData()



JointAcceleration = 2

The joint accelerations, read only, see PxScene::copyArticulationData()



JointForce = 3

The applied joint forces, write only, see PxScene::applyArticulationData()



JointSolverForce = 4

The computed joint constraint solver forces, read only, see PxScene::copyArticulationData()()



JointTargetVelocity = 5

The velocity targets for the joint drives, write only, see PxScene::applyArticulationData()



JointTargetPosition = 6

The position targets for the joint drives, write only, see PxScene::applyArticulationData()



SensorForce = 7

The spatial sensor forces, read only, see PxScene::copyArticulationData()



RootTransform = 8

The root link transform, read and write, see PxScene::copyArticulationData(), PxScene::applyArticulationData()



RootVelocity = 9

The root link velocity, read and write, see PxScene::copyArticulationData(), PxScene::applyArticulationData()



LinkTransform = 10

The link transforms including root link, read only, see PxScene::copyArticulationData()



LinkVelocity = 11

The link velocities including root link, read only, see PxScene::copyArticulationData()



LinkForce = 12

The forces to apply to links, write only, see PxScene::applyArticulationData()



LinkTorque = 13

The torques to apply to links, write only, see PxScene::applyArticulationData()



FixedTendon = 14

Fixed tendon data, write only, see PxScene::applyArticulationData()



FixedTendonJoint = 15

Fixed tendon joint data, write only, see PxScene::applyArticulationData()



SpatialTendon = 16

Spatial tendon data, write only, see PxScene::applyArticulationData()



SpatialTendonAttachment = 17

Spatial tendon attachment data, write only, see PxScene::applyArticulationData()