PxConstraintFlag

Enum PxConstraintFlag 

#[repr(i32)]
pub enum PxConstraintFlag {
Show 13 variants Broken = 1, ProjectToActor0 = 2, ProjectToActor1 = 4, Projection = 6, CollisionEnabled = 8, Visualization = 16, DriveLimitsAreForces = 32, ImprovedSlerp = 128, DisablePreprocessing = 256, EnableExtendedLimits = 512, GpuCompatible = 1_024, AlwaysUpdate = 2_048, DisableConstraint = 4_096,
}
constraint flags

eBROKEN is a read only flag

Variants



Broken = 1

whether the constraint is broken



ProjectToActor0 = 2

whether actor1 should get projected to actor0 for this constraint (note: projection of a static/kinematic actor to a dynamic actor will be ignored)



ProjectToActor1 = 4

whether actor0 should get projected to actor1 for this constraint (note: projection of a static/kinematic actor to a dynamic actor will be ignored)



Projection = 6

whether the actors should get projected for this constraint (the direction will be chosen by PhysX)



CollisionEnabled = 8

whether contacts should be generated between the objects this constraint constrains



Visualization = 16

whether this constraint should be visualized, if constraint visualization is turned on



DriveLimitsAreForces = 32

limits for drive strength are forces rather than impulses



ImprovedSlerp = 128

perform preprocessing for improved accuracy on D6 Slerp Drive (this flag will be removed in a future release when preprocessing is no longer required)



DisablePreprocessing = 256

suppress constraint preprocessing, intended for use with rowResponseThreshold. May result in worse solver accuracy for ill-conditioned constraints.



EnableExtendedLimits = 512

enables extended limit ranges for angular limits (e.g., limit values > PxPi or < -PxPi)



GpuCompatible = 1_024

the constraint type is supported by gpu dynamics



AlwaysUpdate = 2_048

updates the constraint each frame



DisableConstraint = 4_096

disables the constraint. SolverPrep functions won’t be called for this constraint.