Enum physx_sys::PxContactPatchFlags
source · #[repr(i32)]
pub enum PxContactPatchFlags {
HasFaceIndices,
Modifiable,
ForceNoResponse,
HasModifiedMassRatios,
HasTargetVelocity,
HasMaxImpulse,
RegeneratePatches,
CompressedModifiedContact,
}Expand description
Header for a contact patch where all points share same material and normal
Variants
HasFaceIndices
Indicates this contact stream has face indices.
Modifiable
Indicates this contact stream is modifiable.
ForceNoResponse
Indicates this contact stream is notify-only (no contact response).
HasModifiedMassRatios
Indicates this contact stream has modified mass ratios
HasTargetVelocity
Indicates this contact stream has target velocities set
HasMaxImpulse
Indicates this contact stream has max impulses set
RegeneratePatches
Indicates this contact stream needs patches re-generated. This is required if the application modified either the contact normal or the material properties
CompressedModifiedContact