#[repr(i32)]
pub enum PxConvexMeshCookingType {
    Quickhull,
}
Enumeration for convex mesh cooking algorithms.

Variants



Quickhull

The Quickhull algorithm constructs the hull from the given input points. The resulting hull will only contain a subset of the input points.