Enum physx_sys::PxD6Motion
source · #[repr(i32)]
pub enum PxD6Motion {
Locked,
Limited,
Free,
}Expand description
Used to specify the range of motions allowed for a degree of freedom in a D6 joint.
Variants
Locked
The DOF is locked, it does not allow relative motion.
Limited
The DOF is limited, it only allows motion within a specific range.
Free
The DOF is free and has its full range of motion.