PxErrorCode

Enum PxErrorCode 

#[repr(i32)]
pub enum PxErrorCode { NoError = 0, DebugInfo = 1, DebugWarning = 2, InvalidParameter = 4, InvalidOperation = 8, OutOfMemory = 16, InternalError = 32, Abort = 64, PerfWarning = 128, MaskAll = -1, }
Error codes

These error codes are passed to PxErrorCallback

Variants



NoError = 0



DebugInfo = 1

An informational message.



DebugWarning = 2

a warning message for the user to help with debugging



InvalidParameter = 4

method called with invalid parameter(s)



InvalidOperation = 8

method was called at a time when an operation is not possible



OutOfMemory = 16

method failed to allocate some memory



InternalError = 32

The library failed for some reason. Possibly you have passed invalid values like NaNs, which are not checked for.



Abort = 64

An unrecoverable error, execution should be halted and log output flushed



PerfWarning = 128

The SDK has determined that an operation may result in poor performance.



MaskAll = -1

A bit mask for including all errors