#[repr(i32)]pub enum PxForceMode {
Force = 0,
Impulse = 1,
VelocityChange = 2,
Acceleration = 3,
}Expand description
Parameter to addForce() and addTorque() calls, determines the exact operation that is carried out.
Variants
Force = 0
parameter has unit of mass * length / time^2, i.e., a force
Impulse = 1
parameter has unit of mass * length / time, i.e., force * time
VelocityChange = 2
parameter has unit of length / time, i.e., the effect is mass independent: a velocity change.
Acceleration = 3
parameter has unit of length/ time^2, i.e., an acceleration. It gets treated just like a force except the mass is not divided out before integration.