#[repr(i32)]pub enum PxHeightFieldFlag {
NoBoundaryEdges = 1,
}Expand description
Enum with flag values to be used in PxHeightFieldDesc.flags.
Variants
NoBoundaryEdges = 1
Disable collisions with height field with boundary edges.
Raise this flag if several terrain patches are going to be placed adjacent to each other, to avoid a bump when sliding across.
This flag is ignored in contact generation with sphere and capsule shapes.