Enum physx_sys::PxMeshFlag
source · #[repr(i32)]
pub enum PxMeshFlag {
Flipnormals,
E16BitIndices,
}Expand description
Enum with flag values to be used in PxSimpleTriangleMesh::flags.
Variants
Flipnormals
Specifies if the SDK should flip normals.
The PhysX libraries assume that the face normal of a triangle with vertices [a,b,c] can be computed as: edge1 = b-a edge2 = c-a face_normal = edge1 x edge2.
Note: This is the same as a counterclockwise winding in a right handed coordinate system or alternatively a clockwise winding order in a left handed coordinate system.
If this does not match the winding order for your triangles, raise the below flag.
E16BitIndices
Denotes the use of 16-bit vertex indices