PxMetaDataFlag

Enum PxMetaDataFlag 

#[repr(i32)]
pub enum PxMetaDataFlag {
Show 18 variants Class = 1, Virtual = 2, Typedef = 4, Ptr = 8, Handle = 16, ExtraData = 32, ExtraItem = 64, ExtraItems = 128, ExtraName = 256, Union = 512, Padding = 1_024, Alignment = 2_048, CountMaskMsb = 4_096, CountSkipIfOne = 8_192, ControlFlip = 16_384, ControlMask = 32_768, ControlMaskRange = 255, ForceDword = 2_147_483_647,
}
Flags used to configure binary meta data entries, typically set through PX_DEF_BIN_METADATA defines.

Variants



Class = 1

declares a class



Virtual = 2

declares class to be virtual



Typedef = 4

declares a typedef



Ptr = 8

declares a pointer



Handle = 16

declares a handle



ExtraData = 32

declares extra data exported with PxSerializer::exportExtraData



ExtraItem = 64

specifies one element of extra data



ExtraItems = 128

specifies an array of extra data



ExtraName = 256

specifies a name of extra data



Union = 512

declares a union



Padding = 1_024

declares explicit padding data



Alignment = 2_048

declares aligned data



CountMaskMsb = 4_096

specifies that the count value’s most significant bit needs to be masked out



CountSkipIfOne = 8_192

specifies that the count value is treated as zero for a variable value of one - special case for single triangle meshes



ControlFlip = 16_384

specifies that the control value is the negate of the variable value



ControlMask = 32_768

specifies that the control value is masked - mask bits are assumed to be within eCONTROL_MASK_RANGE



ControlMaskRange = 255

mask range allowed for eCONTROL_MASK



ForceDword = 2_147_483_647