PxQueryFlag

Enum PxQueryFlag 

#[repr(i32)]
pub enum PxQueryFlag { Static = 1, Dynamic = 2, Prefilter = 4, Postfilter = 8, AnyHit = 16, NoBlock = 32, DisableHardcodedFilter = 64, Reserved = 32_768, }
Filtering flags for scene queries.

Variants



Static = 1

Traverse static shapes



Dynamic = 2

Traverse dynamic shapes



Prefilter = 4

Run the pre-intersection-test filter (see PxQueryFilterCallback::preFilter)



Postfilter = 8

Run the post-intersection-test filter (see PxQueryFilterCallback::postFilter)



AnyHit = 16

Abort traversal as soon as any hit is found and return it via callback.block. Helps query performance. Both eTOUCH and eBLOCK hitTypes are considered hits with this flag.



NoBlock = 32

All hits are reported as touching. Overrides eBLOCK returned from user filters with eTOUCH. This is also an optimization hint that may improve query performance.



DisableHardcodedFilter = 64

Same as eBATCH_QUERY_LEGACY_BEHAVIOUR, more explicit name making it clearer that this can also be used with regular/non-batched queries if needed.



Reserved = 32_768

Reserved for internal use